/*
 * Copyright 2007 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License")
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sf.hibernate4gwt.core.beanlib;

import net.sf.beanlib.hibernate.HibernateBeanReplicator;
import net.sf.beanlib.hibernate3.Hibernate3BeanTransformer;
import net.sf.beanlib.hibernate3.Hibernate3BlobReplicator;
import net.sf.beanlib.hibernate3.Hibernate3CollectionReplicator;
import net.sf.beanlib.hibernate3.Hibernate3MapReplicator;

/**
 * Hibernate Bean Replicator override to inject the class mapper used for clone 
 * to a different class.
 * @author bruno.marchesson
 */
public class CloneBeanReplicator extends HibernateBeanReplicator
{
	public CloneBeanReplicator(CloneMapper cloneMapper) {
		super(newBeanTransformer(cloneMapper));
	}
	
	private static Hibernate3BeanTransformer newBeanTransformer(CloneMapper cloneMapper) 
    {
        Hibernate3BeanTransformer transformer = Hibernate3BeanTransformer.newBeanTransformer();
        
        // Custom collection replicatable
        transformer.initCollectionReplicatable(
                Hibernate3CollectionReplicator.getFactory());
        		// MappedClassCollectionReplicator.factory);
        // ((MappedClassCollectionReplicator)transformer.getCollectionReplicatable()).setCloneMapper(cloneMapper);

        transformer.initMapReplicatable(
                Hibernate3MapReplicator.getFactory());
        transformer.initBlobReplicatable(
                Hibernate3BlobReplicator.getFactory());
        
        
        transformer.initBeanReplicatable(
                // Hibernate3JavaBeanReplicator.getFactory());
        		MappedClassBeanReplicator.factory);
        ((MappedClassBeanReplicator)transformer.getBeanReplicatable()).setCloneMapper(cloneMapper);

        return transformer;
    }
}