/*
 * Copyright 2007 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License")
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sf.hibernate4gwt.core.beanlib;

/**
 * Class mapper handler for clone or merge operation.
 * It encapsulates a unified class mapper for the clone or merge operation only because
 * beanlib replicators must be stateless and do not have to know if they do a clone or a merge
 * operation
 * @author bruno.marchesson
 *
 */
public class CloneMapper
{
	//----
	// Attributes
	//----
	/**
	 * The encapsulated class mapper
	 */
	private IClassMapper _classMapper;
	
	/**
	 * Indicator for clone or merge operation
	 */
	private boolean _clone;
	
	//----
	// Constructor
	//----
	/**
	 * Constructor
	 */
	public CloneMapper(IClassMapper classMapper, boolean clone)
	{
		_classMapper = classMapper;
		_clone = clone;
	}
	
	//----
	// Public interface
	//----
	/**
	 * Returns the mapped class
	 */
	public Class getMappedClass(Class clazz)
	{
		Class result = null;
		
	//	Call the right method
	//
		if (_clone == true)
		{
			result = _classMapper.getTargetClass(clazz);
		}
		else
		{
			result = _classMapper.getSourceClass(clazz);
		}
		
	//	If there is no mapped class, keep the source class
	//
		if (result == null)
		{
			result = clazz;
		}
		return result;
	}
}
