/*
 * Copyright 2007 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License")
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.hibernate4gwt.core.beanlib;

import java.lang.reflect.Method;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.Hibernate;

import net.sf.beanlib.spi.DetailedBeanPopulatable;
import net.sf.hibernate4gwt.pojo.ILazyPojo;

/**
 * Populatable for Hibernate lazy handling
 * @author bruno.marchesson
 */
public class FromHibernateToLazyBeanPopulatable implements DetailedBeanPopulatable 
{
	//----
	// Properties
	//----
	/**
	 * Log channel
	 */
	private static Log _log = LogFactory.getLog(FromHibernateToLazyBeanPopulatable.class);
	
	//-------------------------------------------------------------------------
	//
	// DetailedBeanPopulatable implementation
	//
	//-------------------------------------------------------------------------
	/* (non-Javadoc)
	 * @see net.sf.beanlib.spi.DetailedBeanPopulatable#shouldPopulate(java.lang.String, java.lang.Object, java.lang.reflect.Method, java.lang.Object, java.lang.reflect.Method)
	 */
	public boolean shouldPopulate(String propertyName, 
								  Object fromBean, 
								  Method readerMethod, 
								  Object toBean, 
								  Method setterMethod)
	{
	//	Is the property lazy loaded ?
	//
		try
		{
			Object result = readerMethod.invoke(fromBean, new Object[] {});
			if (Hibernate.isInitialized(result) == false)
			{
			//	Lazy property !
			//
				_log.info(fromBean.toString()+ "." + propertyName + " --> lazy loaded ");
				if (toBean instanceof ILazyPojo == true)
				{
				//	Mark as lazy
				//
					((ILazyPojo)toBean).addLazyProperty(propertyName);
				}
				return false;
			}
			else
			{
				return true;
			}
		}
		catch(Exception ex)
		{
			throw new RuntimeException(ex);
		}
	}

}
