/*
 * Copyright 2007 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License")
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sf.hibernate4gwt.core.beanlib;

import net.sf.beanlib.hibernate.UnEnhancer;
import net.sf.beanlib.hibernate3.Hibernate3JavaBeanReplicator;
import net.sf.beanlib.spi.BeanTransformerSpi;
import net.sf.beanlib.spi.replicator.BeanReplicatorSpi;

/**
 * Bean replicator with different from and to classes
 * @author bruno.marchesson
 *
 */
public class MappedClassBeanReplicator extends Hibernate3JavaBeanReplicator
{
	//----
	// Attributes
	//----
	/**
	 * The associated clone mapper
	 */
	private CloneMapper cloneMapper;
	
	//----
	// Properties
	//----
	/**
	 * @return the cloneMapper
	 */
	public CloneMapper getCloneMapper() {
		return cloneMapper;
	}

	/**
	 * @param cloneMapper the cloneMapper to set
	 */
	public void setCloneMapper(CloneMapper cloneMapper) {
		this.cloneMapper = cloneMapper;
	}
	
	//----
	// Factory
	//----
	public static final Factory factory = new Factory();
	
    /**
     * Factory for {@link MappedClassBeanReplicator}
     * 
     * @author bruno.marchesson
     */
    public static class Factory implements BeanReplicatorSpi.Factory {
        private Factory() {}
        
        public MappedClassBeanReplicator newBeanReplicatable(BeanTransformerSpi beanTransformer) {
            return new MappedClassBeanReplicator(beanTransformer);
        }
    }
    
    public static MappedClassBeanReplicator newBeanReplicatable(BeanTransformerSpi beanTransformer) {
        return factory.newBeanReplicatable(beanTransformer);
    }
    
    //----
	// Constructor
	//----
    protected MappedClassBeanReplicator(BeanTransformerSpi beanTransformer) 
    {
        super(beanTransformer);
    }
	
	//----
    // Override
    //----
    @Override
    protected <T> T createToInstance(Class<T> toClass) 
        throws InstantiationException, IllegalAccessException, SecurityException, NoSuchMethodException 
    {
        toClass = UnEnhancer.unenhance(toClass);
        
    //	Clone mapper indirection
    //
        if (cloneMapper != null)
        {
        	toClass = cloneMapper.getMappedClass(toClass);
        }
        return super.createToInstance(toClass);
    }
}
