/*
 * Copyright 2007 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License")
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sf.hibernate4gwt.core.store.stateful;

import java.util.HashMap;

import net.sf.hibernate4gwt.core.store.IPojoStore;

/**
 * In Memory POJO Handler
 * This class stores POJO in a simple hashmap
 * @author bruno.marchesson
 *
 */
public class InMemoryPojoStore implements IPojoStore
{
	//----
	// Attributes
	//----
	/**
	 * The store hashmap
	 */
	protected HashMap _map = new HashMap();
	
	//-------------------------------------------------------------------------
	//
	// IPojoHandler implementation
	//
	//-------------------------------------------------------------------------
	/* (non-Javadoc)
	 * @see org.dotnetguru.lazykiller.web.IPojoHandler#isSteteless()
	 */
	public boolean isStateless()
	{
		return false;
	}
	
	/* (non-Javadoc)
	 * @see net.sf.hibernate4gwt.web.IPojoHandler#remove(javax.servlet.http.HttpServletRequest, java.lang.Object, java.lang.String)
	 */
	public void remove(Object object)
	{
		_map.remove(UniqueNameGenerator.generateUniqueName(object));
	}

	/* (non-Javadoc)
	 * @see net.sf.hibernate4gwt.web.IPojoHandler#restore(javax.servlet.http.HttpServletRequest, java.lang.Object, java.lang.String)
	 */
	public Object restore(Object dto, Class hibernateClass)
	{
		return _map.get(UniqueNameGenerator.generateUniqueName(dto, hibernateClass));
	}

	/* (non-Javadoc)
	 * @see net.sf.hibernate4gwt.web.IPojoHandler#store(javax.servlet.http.HttpServletRequest, java.lang.Object, java.lang.String)
	 */
	public void store(Object object)
	{
		_map.put(UniqueNameGenerator.generateUniqueName(object), object);
	}

}
