/*
 * Copyright 2007 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License")
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sf.hibernate4gwt.core.store.stateless;

import java.io.Serializable;

import net.sf.hibernate4gwt.core.HibernateHelper;

import org.hibernate.HibernateException;
import org.hibernate.Session;

/**
 * Default implementation of the Hibernate loader
 * @author bruno.marchesson
 *
 */
public class DefaultHibernateLoader implements IHibernateLoader
{
	//-------------------------------------------------------------------------
	//
	// Public interface
	//
	//-------------------------------------------------------------------------
	/* (non-Javadoc)
	 * @see org.dotnetguru.lazykiller.web.stateless.IStatelessLoader#load(java.lang.String, org.dotnetguru.lazykiller.pojo.ILazyPojo)
	 */
	public Object load(Object gwtPojo, Class hibernateClass)
	{
		Serializable id = HibernateHelper.getInstance().getId(gwtPojo, hibernateClass);
		
	//	Create a new fresh POJO
	//
		boolean createdSession = false;
		Session session = null;
		try
		{
			try
			{
				session = HibernateHelper.getInstance().getSessionFactory().getCurrentSession();
			}
			catch(HibernateException ex)
			{
			//	No session : create a new one
			//
				session = HibernateHelper.getInstance().getSessionFactory().openSession();
				createdSession = true;
			}
			
			return session.get(hibernateClass, id);
		}
		finally
		{
			if ((createdSession == true) &&
				(session != null))
			{
				session.close();
			}
		}
	}
}
