/*
 * Copyright 2007 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License")
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sf.hibernate4gwt.pojo.gwt;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import com.google.gwt.user.client.rpc.IsSerializable;

import net.sf.hibernate4gwt.pojo.ILazyPojo;

/**
 * Abstract POJO for GWT with lazy property handling
 * Note : this class cannot inherit from the abstract LazyPojo
 * The GWT compiler will not convert the lazy properties list
 * since they do not come from a IsSerializable class... 
 * @author bruno.marchesson
 *
 */
public abstract class LazyGwtPojo implements ILazyPojo, IsSerializable, Serializable
{
	//-----
	// Attributes
	//-----
	/**
	 * List of lazy but not loaded properties
	 * @gwt.typeArgs <java.lang.String>
	 */
	protected List _lazyProperties;
	
	//-------------------------------------------------------------------------
	//
	// Constructor
	//
	//-------------------------------------------------------------------------
	/**
	 * Constructor
	 */
	public LazyGwtPojo()
	{
		super();
		_lazyProperties = new ArrayList();
	}
	
	//-------------------------------------------------------------------------
	//
	// Public interface
	//
	//-------------------------------------------------------------------------
	/* (non-Javadoc)
	 * @see org.dotnetguru.lazykiller.pojo.ILazyPojo#addLazyProperty(java.lang.String)
	 */
	public void addLazyProperty(String property)
	{
		_lazyProperties.add(property);
	}
	
	/* (non-Javadoc)
	 * @see org.dotnetguru.lazykiller.pojo.ILazyPojo#isLazyProperty(java.lang.String)
	 */
	public boolean isLazyProperty(String property)
	{
		return _lazyProperties.contains(property);
	}
	
	/* (non-Javadoc)
	 * @see org.dotnetguru.lazykiller.pojo.ILazyPojo#getLazyString()
	 */
	public String getLazyString()
	{
		StringBuffer result = new StringBuffer();
		
		for (int index = 0 ; index < _lazyProperties.size() ; index ++)
		{
			result.append(_lazyProperties.get(index));
			result.append(' ');
		}
		
		return result.toString();
	}
}
