/*
 * Copyright 2007 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License")
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sf.hibernate4gwt.rebind;


/**
 * This wrapping class loader is used to generate proxy every time
 * that a IProxy assignable class is loaded
 * @author bruno.marchesson
 *
 */
public class ProxyClassLoader extends ClassLoader
{
	//----
	// Attributes
	//----
	/*
	 * The wrapped class loader
	 */
	private ClassLoader _wrappedClassLoader;
	
	//-------------------------------------------------------------------------
	//
	// Constructor
	//
	//-------------------------------------------------------------------------
	/**
	 * Constructor
	 */
	public ProxyClassLoader(ClassLoader wrappedClassLoader)
	{
		_wrappedClassLoader = wrappedClassLoader;
	}
	
	//-------------------------------------------------------------------------
	//
	// Class loader overrides
	//
	//-------------------------------------------------------------------------
	/**
	 * Load class wrapping
	 */
	public Class loadClass(String name) throws ClassNotFoundException
	{
		if (ProxyGeneratorHelper.isProxy(name))
		{
		//	Get source class name
		//
			String sourceClassName = ProxyGeneratorHelper.getProxifiedClass(name);
			Class sourceClass = _wrappedClassLoader.loadClass(sourceClassName);
			
		//	Generate proxy 
		//
			return ProxyManager.getInstance().generateProxyClass(sourceClass);
		}
		else
		{
		//	Load class
		//
			return _wrappedClassLoader.loadClass(name);
		}
	}

}
